# Use Case 1 - Getting Data from an External Third Party

This use case demonstrates how **RAD Cycles** can orchestrate their data workflows using **Control-M MFT/MFTE**.

RAD Cycles receives **raw order material** from authorized third-party providers across multiple countries. This data needs to be sent to **AWS S3** for analysis. 

>
>__Approach:__
>We will use Control-M MFTE to retrieve data from the external third party. Then, Control-M MFT will automatically transfer the data to AWS S3. Finally, the order data will be processed, generating an order bill, which will be sent back to the user via an MFT Job.


## **MFT/E Tech Day - Accesses**
RAD Cycles utilizes an **AWS environment** for its **data pipeline** and analysis through various AWS services.

The following use cases highlight some current challenges faced by **RAD Cycles** and how **Control-M MFT/E** capabilities—including **native integrations** and **governance controls**—help resolve these challenges.

Use the links below to proceed to the next use cases:<div>
<b>Control-M Web</b>:  https://ec2-13-38-25-95.eu-west-3.compute.amazonaws.com:8446/ControlM/
</div>
<div>
<b>Control-M Web Configuration</b>: https://ec2-13-38-25-95.eu-west-3.compute.amazonaws.com:8446/Configuration
</div>
<div>
<b>Control-M MFTE Environment</b>: https://ec2-13-38-25-95.eu-west-3.compute.amazonaws.com:8446/mfte/environment
</div>
<div>
<b>MFT Gateway Exchange</b>: https://ec2-13-37-217-250.eu-west-3.compute.amazonaws.com:9443/
</div>
<div>
</div>

>
>__Note__: 
>Each of you will have a user name that will be provided <b>by the instructor</b> during the technical session. 


## **Step 1 - MFTE Configuration**

1. **Access MFTE Enterprise Configuration:**
   - In **Control-M Web**, click the **three dots** in the upper-right corner.
   - Select **MFT Enterprise**.
   <div>
   <p align="center">
   <img src="images/Access_MFTE.png" alt="MFTE Configuration" class="img-bordered">
   </p>
   </div>

2. **Create Your MFTE User:**
   - Navigate to the **Users** tab and click **Add User**.
   - Enter your **student ID** as the username (e.g., `student01`).
   <div>
   <p align="center">
   <img src="images/1_AddUser.png" alt="MFTE User" class="img-bordered">
   </p>
   </div>

   - Check **“Generate Password”** (you will receive the password via email once the user is created).
   <div>
   <p align="center">
   <img src="images/AddUser.png" alt="MFTE User Generate Password">
   </p>
   </div>

   - Ensure **“User must log in to File Exchange and change password”** is selected.
   - Finally click on <b>Add</b>


3. **Log in to File Exchange:**
   - Check your email for the **password**.
   <div>
   <p align="center">
   <img src="images/emailAddUser.png" alt="MFTE User Add User">
   </p>
   </div>

   - Click the **File Exchange link** received via email or, alternatively, click this link and change your password during your first login: https://ec2-13-37-217-250.eu-west-3.compute.amazonaws.com:9443/
   <div>
   <p align="center">
   <img src="images/loginUser.png" alt="MFTE User Login User">
   </p>
   </div>

   - Once the password is changed, you will receive an email notifying it.
   <div>
   <p align="center">
   <img src="images/userPasswordChanged.png" alt="MFTE User Password Changed">
   </p>
   </div>

4. **Create a Virtual Folder:**
   - Navigate back to the **MFT Enterprise Configuration** page.
   - Click on **Virtual Folders** and select **Add Virtual Folder**.
   <div>
   <p align="center">
   <img src="images/1_addVirtualFolder.png" alt="MFTE Add Virtual Folder 1">
   </p>
   </div>

   - Name it the **same as your user ID**.
   - Observe the **permissions** for virtual folders and sub-folders—these restrict external trading partners to only necessary access.
   <div>
   <p align="center">
   <img src="images/addVirtualFolder.png" alt="MFTE Add Virtual Folder 2">
   </p>
   </div>

   - Update the **Policy Section** accordingly, then click **Add**.
   <div>
   <p align="center">
   <img src="images/addVirtualFolderPolicy.png" alt="MFTE Add Policy">
   </p>
   </div>

5. **Modify MFTE Rules:**
   - Navigate to the **Rules** section.
   - Search for the rule named **TechDayRule**.
   - Select the rule and click **Duplicate**.
   <div>
   <p align="center">
   <img src="images/duplicateRule.png" alt="MFTE Rule Duplicate">
   </p>
   </div>

   - Rename it by appending your **student ID** (e.g., `TechDayRule_student01`).
   <div>
   <p align="center">
   <img src="images/duplicateRuleStudent.png" alt="MFTE Rule Student">
   </p>
   </div>

   - Update the **Condition**:
     - Go to to *If file arrives in a specific virtual folder*
         - Replace the <b>admin</b> Virtual Folder and search for and update the condition with your **Virtual Folder name** e.g. student99  
     - Keep the condition <b>“If file pattern is orderID*.csv”</b> as is.
   - Click **Duplicate**.

## **Step 2 - Centralized Conection Profile and Workflow Creation**

1. **Open Control-M Web:**
   - Go to **Planning Domain**.
   - In **Folders and Jobs**, filter by folder name **MFT_Sales_Analysis-student00**.
   <div>
   <p align="center">
   <img src="images/planningDomainFolders.png" alt="Planning Domain">
   </p>
   </div>

   - Open the workspace do **not modify it**, and click on ![workspace](images/duplicate.png) (New dialog will be opened).

   - Under <b>Name</b> provide your studentID e.g. student99 and click on <b>Duplicate</b> (new tab) will be opened

   <div>
   <p align="center">
   <img src="images/duplicateWorkspace.png" alt="Planning domain New">
   </p>
   </div>

2. On the new workspace select the folder and rename it with the following definition. 

   <div style="text-align: center;">
    <table>
    <thead>
        <tr>
        <th style="text-align: left; background-color: #0073e6; color: white;">Parameter</th>
        <th style="text-align: left; background-color: #0073e6; color: white;">Value</th>
        </tr>
    </thead>
    <tbody>
        <tr>
        <td><b>Folder Name</b></td>
        <td><code>MFT_Sales_Analysis-<b>&#60;YOUR_studentID&#62;</b></code></td>
        </tr>
        <tr>
        <td><b>Run Method</b></td>
        <td><code>Manual</code></td>
        </tr>
        <tr>
        <td><b>Application</b></td>
        <td><code>MFT</code></td>
        </tr>
        <tr>
        <td><b>Sub Application</b></td>
        <td><code>MFT</code></td>
        </tr>
        <tr>
        <td><b>Site Standard</b></td>
        <td><code>MFT-TechDay</code></td>
        </tr>
    </tbody>
    </table>
    </div>

   - Your folder should have the definition like the image below. 

   <div>
      <p align="center">
         <img src="images/folderDefinition.png" alt="Create Workspace">
      </p>
   </div>

3. **Check Connection Profile in job `get-order-data-to-S3`:**
   <div>
   <p align="center">
   <img src="images/get_order_s3_connection_profile.png" alt="Connection Profile">
   </p>
   </div>

   - Click the **three dots** in the upper-right corner and select **Configuration**.
   <div>
   <p align="center">
   <img src="images/configurationDomain.png" alt="Configuration Domain">
   </p>
   </div>

   - Click the **orange arow** and select **Centralized Connection Profiles**.
   <div>
   <p align="center">
   <img src="images/centralizedConnectionProfiles.png" alt="CCP">
   </p>
   </div>

   - Filter by **File Transfer Plugin** and search for **AWS**.
   <div>
   <p align="center">
   <img src="images/centralizedConnectionProfilesFileTransferSearch.png" alt="CCP Search">
   </p>
   </div>

4. **Update Connection Profile:**
   - There are two highlighted **Connection Profiles**:
     - `DAV_AWS` (uses **Access Key & Secret Key** for S3 access).
     - `AWS_IAM_ROLE` (uses an **IAM Role** instead of access keys).
   <div>
   <p align="center">
   <img src="images/centralizedConnectionProfilesFileTransferSearchAWS.png" alt="CCCP Search AWS">
   </p>
   </div>

    >
    >__Note__: 
    >The difference here is that the `DAV_AWS CCP` connects to `AWS S3` using only the `Access Key and Secret Access Key method`. This means that any policies linked to that Access Key will apply, granting access to everything specified in those policies. In this case, it allows access to `all S3 buckets`.
    >
    > Now, imagine a scenario where you `don’t want to use Access Keys` for authorization but prefer using an `IAM role` instead. This is where a new `Connection Profile Parameter` called `s3.role.arn` comes in.
    >
    >If you check the other Connection Profile highlighted, you’ll see an extra parameter added with the value `arn:aws:iam::390426403709:role/drc-dba-mft-tech-day`. This means that an `AWS IAM role is being used for authorization` instead of Access Keys.
    <div>
   <p align="center">
   <img src="images/centralizedConnectionProfilesManualParameter.png" alt="CCP Manual Parameter">
   </p>
   </div>
   
   - If we take a look at AWS for permissions associated with this role, it is restricted only to one S3 bucket. 
   - Here is the associated policy with the role restricted to S3 Bucket: 
drc-dba-mft-tech-day
   <div>
   <p align="center">
   <img src="images/awsPolicy.png" alt="AWS Policy">
   </p>
   </div>

   - To enhance security, switch to **AWS_IAM_ROLE**, which restricts access to a specific **S3 bucket**.
   - In the **get-order-data-to-S3** job:
     - Navigate to the **Connection Profile**.
     - Click the **three dots** and replace `DAV_AWS` with `AWS_IAM_ROLE`.
     <div>
     <p align="center">
     <img src="images/updateConnectionProfile.png" alt="Update CCP">
     </p>
     </div>

     - Click **Select**.
     <div>
     <p align="center">
     <img src="images/updateConnectionProfileReplace.png" alt="Update CCP Replace">
     </p>
     </div>

     - You will notice the bucket definition is empty 
     <div>
     <p align="center">
     <img src="images/updateConnectionProfileSelectBucket.png" alt="select bucket">
     </p>
     </div>

     - Now if you try to browse through buckets, the associated **IAM Role policy** limits access. 
     <div>
     <p align="center">
     <img src="images/updateConnectionProfileSelectBucketEmpty.png" alt="Bucket Empty">
     </p>
     </div>

     - Hence you need to manually enter Bucket name as `drc-dba-mft-tech-day`
     <div>
     <p align="center">
     <img src="images/updateConnectionProfileManualDefinition.png" alt="CCP Manual Definition">
     </p>
     </div>

     - Under the file transfer definition include the following definition: 
        **Left side:**
        ```
        /b2bhome/%%user/incoming/orderID_%%user..csv
        ```
        **Right side:**
        ```
        /orders/provider_id=%%user/
        ```

   - The defition should be as the image below: 
   <div>
   <p align="center">
   <img src="images/updateConnectionProfileFileTransferDef.png" alt="CCp Transfer Definition">
   </p>
   </div>

   >
   >__Note__:
   >*We are using variables on the file transfer definition, which comes from the Rule defined on the MFTE Section (we will see it on the following steps).*
<div>
</div>

   - Once changes are done, save and check-in the folder.
   <div>
   <p align="center">
   <img src="images/saveCheckIn.png" alt="SaveCheckin">
   </p>
   </div>



## **Step 3 - Updating MFTE Rule**

1. **Locate Your Rule:**
   - Navigate to the rule you created earlier (e.g., `TechDayRule_student01`).

2. **Modify Actions:**
   - Under **Run Folder**, replace with:  
     `MFT_Sales_Analysis-Your_student_ID` (e.g., `MFT_Sales_Analysis-student01`).
     <div>
     <p align="center">
     <img src="images/ruleActions.png" alt="Rule Actions">
     </p>
     </div>

   - Observe the **email notification action**—this should remain unchanged.
   <div>
   <p align="center">
   <img src="images/ruleNotifyEmail.png" alt="Rule Notify Email">
   </p>
   </div>

   - Once the file is uploaded, you will receive an email confirmation with details of the received file.

3. **Save Changes:**
   - Click **Save**.


## **Summary**
Congratulations! You have successfully:
<div>

✅ Configured **MFTE users and virtual folders**.
</div>
<div>

✅ Defined and modified **MFTE rules**.
</div>
<div>

✅ Created a **Control-M MFT workflow**.
</div>
<div>

✅ Integrated **AWS IAM Roles** for secure file transfers.
</div>

<div>
You now have the basic knowledge to leverage **Control-M MFTE** for automated and secure data exchanges.
</div>

**Continue to** [Use Case 2](https://ctm-git.trybmc.com/automation-api-tech-day-customer-repository/foundation-managed-file-transfer-enterprise/use-case-2-process-data-from-external-third-party), where we will automatically process the received data

